@@ -4,7 +4,7 @@ use warnings;
 
 use Moose;
 use LWP::UserAgent;
-use JSON;
+use JSON::MaybeXS;
 
 has useragent => (
     is => 'ro', isa => 'LWP::UserAgent',
@@ -25,7 +25,7 @@ sub get_indexes
     if ($response->code ne '200'
         or $response->headers->content_type ne 'application/json')
     {
-        warn "network timeout when fetching $url" if $response->decoded_content =~ /^read timeout/;
+        warn "network timeout when fetching $url" if $response->decoded_content =~ /time(?:d )?out/;
         return;
     }
 
